@@ -31,11 +31,13 @@ import logging
 
 from sqlalchemy.orm import joinedload_all
 
+from locsms.db import Session as SmsSession
+from locsms.db import model as locsms
+
 import edbob
 from edbob.time import localize
 from edbob.util import requires_impl
 
-import rattail_locsms as locsms
 from rattail.core import Object
 from rattail.gpc import GPC
 from rattail.db import Session
@@ -78,7 +80,7 @@ class LoadProcessor(Object):
             session.close()
             raise DataAlreadyLoadedError
 
-        sms_session = locsms.Session()
+        sms_session = SmsSession()
 
         cancel = False
         for loader in self.relevant_loaders():
@@ -188,10 +190,7 @@ class StoreLoader(DataLoader):
     """
     Loads :class:`rattail_locsms.Store` data into Rattail.
     """
-
-    @property
-    def sms_class(self):
-        return locsms.Store
+    sms_class = locsms.Store
 
     def load_sms_instance(self, sms_store):
         store = model.Store(id=sms_store.F1056)
@@ -210,10 +209,7 @@ class DepartmentLoader(DataLoader):
     """
     Loads :class:`rattail_locsms.Department` data into Rattail.
     """
-
-    @property
-    def sms_class(self):
-        return locsms.Department
+    sms_class = locsms.Department
 
     def load_sms_instance(self, sms_dept):
         dept = model.Department(number=sms_dept.F03)
@@ -225,10 +221,7 @@ class SubdepartmentLoader(DataLoader):
     """
     Loads :class:`rattail_locsms.Subdepartment` data into Rattail.
     """
-
-    @property
-    def sms_class(self):
-        return locsms.Subdepartment
+    sms_class = locsms.Subdepartment
 
     def relevant_cachers(self):
         yield cache.DepartmentCacher, 'departments'
@@ -252,10 +245,7 @@ class VendorLoader(DataLoader):
     """
     Loads :class:`rattail_locsms.Vendor` data into Rattail.
     """
-
-    @property
-    def sms_class(self):
-        return locsms.Vendor
+    sms_class = locsms.Vendor
 
     def load_sms_instance(self, sms_vendor):
         vendor = model.Vendor(id=sms_vendor.F27)
@@ -292,10 +282,7 @@ class ProductLoader(DataLoader):
     """
     Loads :class:`rattail_locsms.Product` data into Rattail.
     """
-
-    @property
-    def sms_class(self):
-        return locsms.Product
+    sms_class = locsms.Product
 
     def relevant_cachers(self):
         yield cache.DepartmentCacher, 'departments'
@@ -369,10 +356,7 @@ class CostLoader(DataLoader):
     """
     Loads :class:`rattail_locsms.Cost` data into Rattail.
     """
-
-    @property
-    def sms_class(self):
-        return locsms.Cost
+    sms_class = locsms.Cost
 
     def relevant_cachers(self):
         yield cache.ProductCacher, 'products'
@@ -428,10 +412,7 @@ class PriceLoader(DataLoader):
     """
     Loads :class:`rattail_locsms.Price` data into Rattail.
     """
-
-    @property
-    def sms_class(self):
-        return locsms.Price
+    sms_class = locsms.Price
 
     def relevant_cachers(self):
         yield cache.ProductCacher, 'products'
@@ -551,10 +532,7 @@ class CustomerGroupLoader(DataLoader):
     """
     Loads :class:`rattail_locsms.CustomerGroup` data into Rattail.
     """
-
-    @property
-    def sms_class(self):
-        return locsms.CustomerGroup
+    sms_class = locsms.CustomerGroup
 
     def load_sms_instance(self, sms_group):
         group = model.CustomerGroup()
@@ -567,10 +545,7 @@ class CustomerLoader(DataLoader):
     """
     Loads :class:`rattail_locsms.Customer` data into Rattail.
     """
-
-    @property
-    def sms_class(self):
-        return locsms.Customer
+    sms_class = locsms.Customer
 
     def relevant_cachers(self):
         yield cache.CustomerGroupCacher, 'groups'
@@ -618,10 +593,7 @@ class OperatorLoader(DataLoader):
     """
     Loads :class:`rattail_locsms.Operator` data into Rattail.
     """
-
-    @property
-    def sms_class(self):
-        return locsms.Operator
+    sms_class = locsms.Operator
 
     def relevant_cachers(self):
         yield cache.CustomerCacher, 'customers'
